.. _gettingstarted:

Getting started
===============

This guide will show you how to get started with curious.

Installing
----------

The first step to getting your bot ready is by installing the library.
curious is available on PyPI under ``discord-curious``:

.. code-block:: bash

   $ pip install -U discord-curious

It is recommended to install curious via PyPI, but if you desire the new
cutting edge features, you can install directly from Git:

.. code-block:: bash

   $ pip install -U git+https://github.com/SunDwarf/curious.git#egg=curious

curious is designed to work with the **latest** version of curio on PyPI,
but if you want access to cutting edge features, you can also install that
from Git:

.. code-block:: bash

   $ pip install -U git+https://github.com/dabeaz/curio.git

Creating a bot account
----------------------

In order to use curious effectively, you need to create a bot account. If
you are unsure how to create one, please consult this tutorial:

https://www.youtube.com/watch?v=yQhdjAWmObM
